============
Installation
============


Using PyPI
=========

To install the package from `PyPi <https://pypi.org/project/epivizFileServer/>`_,

.. code-block:: console

    pip install epivizfileserver


Development Version
===================

To install the development version from `GitHub
<https://github.com/epiviz/epivizFileParser>`__: Install using pip

.. code-block:: console

    pip install git@github.com:epiviz/epivizFileParser.git

you can also clone the repository and install from local directory using `pip`

.. note::

    If you don't have sudo rights to install the package, 
    you can install it to the user directory using 

    .. code-block:: console

        pip install --user epivizfileserver